@@ -1,4 +1,3 @@
-/* $XFree86: xc/programs/Xserver/Xext/xf86vmode.c,v 3.58 2003/11/06 18:37:57 tsi Exp $ */
 
 /*
 
@@ -29,8 +28,6 @@ or other dealings in this Software without prior written authorization
 from Kaleb S. KEITHLEY
 
 */
-/* $XdotOrg: xserver/xorg/hw/xfree86/dixmods/extmod/xf86vmode.c,v 1.8 2005/07/16 03:49:58 kem Exp $ */
-/* $Xorg: xf86vmode.c,v 1.3 2000/08/17 19:47:59 cpqbld Exp $ */
 /* THIS IS NOT AN X CONSORTIUM STANDARD OR AN X PROJECT TEAM SPECIFICATION */
 
 #ifdef HAVE_XORG_CONFIG_H
@@ -52,10 +49,6 @@ from Kaleb S. KEITHLEY
 #include "xf86.h"
 #include "vidmodeproc.h"
 
-#ifdef EXTMODULE
-#include "xf86_ansic.h"
-#endif
-
 #define DEFAULT_XF86VIDMODE_VERBOSITY	3
 
 static int VidModeErrorBase;
@@ -1593,8 +1586,10 @@ ProcXF86VidModeGetGammaRamp(ClientPtr client)
 	    return BadAlloc;
    
         if (!VidModeGetGammaRamp(stuff->screen, stuff->size, 
-		ramp, ramp + length, ramp + (length * 2)))
+		ramp, ramp + length, ramp + (length * 2))) {
+	    xfree(ramp);
             return BadValue;
+	}
     }
 
     rep.type = X_Reply;
